'use strict';
const Schema = require('mongoose').Schema;
const metaPlugin = require('naf-framework-mongoose/lib/model/meta-plugin');
const { Secret } = require('naf-framework-mongoose/lib/model/schema');

// 用户表
const UserSchema = {
  name: { type: String, required: false, maxLength: 200 }, // 名称
  phone: { type: String, required: true, maxLength: 64 }, // 手机
  passwd: { type: Secret, select: false }, // 注册密码
  openid: { type: String, required: false }, // 微信openid
  uid: { type: String, required: false }, // 用户信息id
  role: { type: String, required: false }, // 1-管理员,2-个人,3-企业管理员,4-子管理员,6、专家 7、临时用户
  menus: { type: [ String ], required: false }, // 菜单权限
  pid: { type: String, required: false }, // 父id
  deptname: { type: String, required: false }, // 机构名称
  remark: { type: String, required: false }, // 备注
  code: { type: String, required: false }, // 邀请码
  isdel: { type: String, required: false, default: '0' }, // 0=>未删除;1=>已删除
};


const schema = new Schema(UserSchema, { toJSON: { virtuals: true } });
schema.index({ openid: 1 });
schema.index({ mobile: 1 });
schema.plugin(metaPlugin);

module.exports = app => {
  const { mongoose } = app;
  return mongoose.model('User', schema, 'user');
};
